@@ -233,21 +233,21 @@ class Classifier:
         try:
             self.model = load_model(path+'Keras_Model.h5')
             model = 'model'
-        except FileNotFoundError:
+        except:
             model = ''
             pass
 
         try:
             self.optimization_results = joblib.load(path+'HyperOpt_Results')
             optimization_results = 'optimization_results'
-        except FileNotFoundError:
+        except:
             optimization_results = '' 
             pass
 
         try:
             self.best_params = joblib.load(path+'Best_Params')
             best_params = 'best_params'
-        except FileNotFoundError:
+        except:
             best_params = '' 
             pass        
 
@@ -262,14 +262,9 @@ class Classifier:
 
         Args:
             data: 2D array for single image, 3D array for multiple images.
-            model: The trained Tensorflow model.
-            normalize (bool, optional): True will normalize the data using the input min and max pixels
-            min_pixel (int, optional): The minimum pixel count, defaults to 638. 
-                Pixels with counts below this threshold will be set to this limit.
-            max_pixel (int, optional): The maximum pixel count, defaults to 3000. 
-                Pixels with counts above this threshold will be set to this limit.
             target (str): The name of the target class, assuming binary classification in 
                 which there is an 'OTHER' class. Defaults to 'DIFFUSE'. 
+                
         Returns:
             The class prediction(s), either 'DIFFUSE' or 'OTHER'.
         """
@@ -288,16 +283,19 @@ class Classifier:
 
         return np.array(output)
 
-    def plot_hyper_opt(self, xlog=True, ylog=False, savefig=False):
+    def plot_hyper_opt(self, xlim=None, ylim=None, xlog=True, ylog=False, savefig=False):
         """
         Plots the hyperparameter optimization history.
     
         Args:
+            xlim: Limits for the x-axis. Ex) xlim = (0, 1000)
+            ylim: Limits for the y-axis. Ex) ylim = (0.9, 0.94)
             xlog (boolean): If True the x-axis will be log-scaled.
                 Defaults to True.
             ylog (boolean): If True the y-axis will be log-scaled.
                 Defaults to False.
 
+
         Returns:
             AxesImage
         """
@@ -313,21 +311,24 @@ class Classifier:
         elif self.metric == 'accuracy':
             ylabel = 'Training Accuracy'
         elif self.metric == 'val_loss':
-            ylabel = 'Validation Loss'
+            ylabel = '1 - Validation Loss'
         elif self.metric == 'loss':
-            ylabel = 'Training Loss'
+            ylabel = '1 - Training Loss'
         else:
             ylabel = 'Optimization Metric'
 
         plt.xlabel('Trial #', size=16)
         plt.ylabel(ylabel, size=16)
         plt.title(('Hyperparameter Optimization History'), size=18)
-        #plt.xlim((1,1e4))
-        #plt.ylim((0.9, 0.935))
         plt.xticks(fontsize=14)
         plt.yticks(fontsize=14)
         plt.grid(True, color='k', alpha=0.35, linewidth=1.5, linestyle='--')
         plt.legend(prop={'size': 16})
+        if xlim is not None:
+            plt.xlim(xlim)
+        if ylim is not None:
+            plt.ylim(ylim)
+        plt.tight_layout()
         if savefig:
             plt.savefig('CNN_Hyperparameter_Optimization.png', bbox_inches='tight', dpi=300)
         else:
